pub struct CompassAppConfig {
pub algorithm: SearchAlgorithmConfig,
pub state: Option<Vec<(String, StateVariableConfig)>>,
pub cost: CostModelConfig,
pub label: Value,
pub mapping: MapModelConfig,
pub graph: GraphConfig,
pub search: OneOrMany<SearchConfig>,
pub plugin: PluginConfig,
pub termination: TerminationModel,
pub system: CompassAppSystemParameters,
pub map_matching: Value,
}Expand description
high-level application configuration that orchestrates together
configuration requirements for the various components making up a
[CompassApp].
Fields
algorithm: SearchAlgorithmConfigstate: Option<Vec<(String, StateVariableConfig)>>cost: CostModelConfiglabel: Valuemapping: MapModelConfiggraph: GraphConfigsearch: OneOrMany<SearchConfig>section containing a single search config or an array of search configs (OneOrMany).
plugin: PluginConfigtermination: TerminationModelsystem: CompassAppSystemParametersmap_matching: ValueImplementations
Sourceimpl CompassAppConfig
impl CompassAppConfig
Sourcepub fn from_str(
config: &str,
config_path: &str,
format: FileFormat,
) -> Result<CompassAppConfig, CompassAppError>
pub fn from_str( config: &str, config_path: &str, format: FileFormat, ) -> Result<CompassAppConfig, CompassAppError>
reads a stringified configuration file with provided format and constructs a CompassAppConfig
Sourceimpl CompassAppConfig
impl CompassAppConfig
Sourcepub fn to_pretty_string(&self) -> Result<String, CompassAppError>
pub fn to_pretty_string(&self) -> Result<String, CompassAppError>
Returns a pretty-printed JSON representation of this config. Useful for debugging and logging the exact configuration being used.
pub fn build_traversal_model_services( &self, builders: &CompassBuilderInventory, ) -> Result<Vec<Arc<dyn TraversalModelService>>, CompassAppError>
pub fn build_constraint_model_services( &self, builders: &CompassBuilderInventory, ) -> Result<Vec<Arc<dyn ConstraintModelService>>, CompassAppError>