pub enum WeightHeuristic {
Haversine,
Custom {
custom_weight_type: CustomWeightType,
},
}Variants
Haversine
computes a weight directly as the haversine distance estimation between trip origin and destination, in kilometers.
Custom
user provides a field of some custom weight type that is used directly for weight estimates.
Fields

custom_weight_type: CustomWeightTypeImplementations
Sourceimpl WeightHeuristic
impl WeightHeuristic
pub fn estimate_weight(&self, query: &Value) -> Result<f64, InputPluginError>