json_array_flatten

Function json_array_flatten 

pub fn json_array_flatten(result: &mut Value) -> Result<Vec<Value>, Value>
flattens the result of input processing into a response vector, ensuring that the nesting and types are correct. returns a new vector of values, moving the valid input processing results into the new flattened vector.