unpack_json_array_as_vec

Function unpack_json_array_as_vec 

pub fn unpack_json_array_as_vec(result: &Value) -> Vec<Value>
flattens the result of input processing in the case that the output of the input plugin is more than one JSON object. but if it is not a JSON array, then wrap it in a Vec.