pub enum TraversalOutputFormat {
Wkt,
Wkb,
Json,
GeoJson,
EdgeId,
}Variants
Implementations
Sourceimpl TraversalOutputFormat
impl TraversalOutputFormat
Sourcepub fn generate_route_output(
&self,
route: &Vec<EdgeTraversal>,
map_model: Arc<MapModel>,
state_model: Arc<StateModel>,
) -> Result<Value, OutputPluginError>
pub fn generate_route_output( &self, route: &Vec<EdgeTraversal>, map_model: Arc<MapModel>, state_model: Arc<StateModel>, ) -> Result<Value, OutputPluginError>
generates output for a route based on the configured TraversalOutputFormat
Sourcepub fn generate_tree_output(
&self,
tree: &SearchTree,
map_model: Arc<MapModel>,
state_model: Arc<StateModel>,
) -> Result<Value, OutputPluginError>
pub fn generate_tree_output( &self, tree: &SearchTree, map_model: Arc<MapModel>, state_model: Arc<StateModel>, ) -> Result<Value, OutputPluginError>
generates output for a tree based on the configured TraversalOutputFormat