flattens the result of input processing into a response vector, ensuring
that the nesting and types are correct. returns a new vector of values,
moving the valid input processing results into the new flattened vector.
flattens the result of input processing into a response vector, ensuring
that the nesting and types are correct. the flatten operation effect occurs
in-place on the function argument via a memory swap.
executes an operation on an input query. maintains the invariant that
input queries should always remain wrapped in a top-level JSON Array
so that we can perform operations like grid search, which transform a
single query into multiple child queries.
flattens the result of input processing in the case that the output of the
input plugin is more than one JSON object. but if it is not a JSON array,
then wrap it in a Vec.