pub fn json_array_flatten_in_place(result: &mut Value) -> Result<(), Value>Expand description
flattens the result of input processing into a response vector, ensuring that the nesting and types are correct. the flatten operation effect occurs in-place on the function argument via a memory swap.