pub fn json_array_op<'a>(
query: &'a mut Value,
op: InputArrayOp<'a>,
) -> Result<(), Value>Expand description
executes an operation on an input query. maintains the invariant that input queries should always remain wrapped in a top-level JSON Array so that we can perform operations like grid search, which transform a single query into multiple child queries.